/***********************************************************************************************************************************
Local Command
***********************************************************************************************************************************/
#ifndef COMMAND_LOCAL_LOCAL_H
#define COMMAND_LOCAL_LOCAL_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Local command
void cmdLocal(int fdRead, int fdWrite);

#endif
